#!/usr/bin/env bash

cat <<EOF | 
armeabi-v7a android-armv7 arm-linux-androideabi-4.8 arm-linux-androideabi
x86 android-x86 x86-4.8 i686-linux-android
EOF

while read arch pattern toolchain target
do
    ar="${ANDROID_NDK:?The ANDROID_NDK variable must be set}/toolchains/${toolchain}/prebuilt/linux-x86_64/${target}/bin/ar"
    mkdir -p "archive/${arch}"
    rm "archive/${arch}/"*.a

    printf "Creating libicu.a archive for ${arch}\n"
    "$ar" rcs "archive/${arch}/libicu.a" $(find buck-out/gen/icu -name '*.o' -type f | grep "icu/common#$pattern") 
    printf "libicu.a created\n\n"

    printf "Creating libjsc.a archive for ${arch}\n"
    "$ar" rcs "archive/${arch}/libjsc.a" $(find buck-out/gen/jsc -name '*.o' -type f | grep "jsc/jsc#$pattern") 
    printf "libjsc.a created\n\n"

    printf "Copying other archives for ${arch}\n"
    cp --verbose $(find buck-out/gen/ -name '*.a' -type f | grep "$pattern") "archive/${arch}" 
    printf "\nArchive created at archive/${arch}\n\n"
    
    if [[ -e "$REACT_ANDROID_ROOT" ]]
    then
        dest="$REACT_ANDROID_ROOT/build/third-party-ndk/jsc/jni/${arch}/"
        mkdir -p "$dest"
        cp --verbose "archive/${arch}/"*.a "$dest"
        printf "\nArchives for ${arch} copied to $dest\n\n"
    else
        printf "\nArchives for ${arch} not copied to react-native source as REACT_ANDROID_ROOT not set. Set it to point to ReactAndroid directory of the react-native source\n\n"
    fi
done

printf "Done.\n"

