#!/usr/bin/env bash

PROJECT_ROOT="$(pwd)"
${ANDROID_NDK:?The ANDROID_NDK variable must be set} 1>/dev/null 2>&1

function link() {
    arch="$1"
    archSpec="$2"
    toolChain="$3"
    linker="$4-g++"
    stripFile="$4-strip"
    march="$5"

    outputPath="${PROJECT_ROOT}/build/tmp/buildReactNdkLib/local/${archSpec}"
    jscOutputPath="${PROJECT_ROOT}/build/third-party-ndk/jsc/jni/${archSpec}"
    gnustlPath="${ANDROID_NDK}/sources/cxx-stl/gnu-libstdc++/4.8/libs/${archSpec}"

    wholeArchive=(
        "${outputPath}/libreactnativejnifb.a"
        "${jscOutputPath}/libwtf.a"
        "${jscOutputPath}/libwtfassertions.a"
        "${jscOutputPath}/libwtfcollation.a"
    )

    noWholeArchive=(
        "${outputPath}/libreactnativefb.a"
        "${outputPath}/libfb.a"
        "${outputPath}/libfolly_json.a"
        "${outputPath}/libglog.a"
        "${outputPath}/libglog_init.a"
        "${outputPath}/libjschelpers.a"
        "${outputPath}/libyoga.a"
        "${outputPath}/libyogacore.a"
        "${outputPath}/libboost.a"
        "${outputPath}/libdouble-conversion.a"
        "${jscOutputPath}/libjscoffsetextractor.a"
        "${jscOutputPath}/libjsc.a"
        "${jscOutputPath}/libicu.a"
        "${gnustlPath}/libgnustl_static.a"
    )
    
    linkerOptions=(
        -shared
        -Wl,-soname,libreactnativejni.so
        -Wl,-whole-archive "${wholeArchive[@]}"
        -Wl,-no-whole-archive "${noWholeArchive[@]}"
        -Wl,--fix-cortex-a8
        -Wl,--no-undefined
        -Wl,-z,relro
        -Wl,-z,noexecstack
        -Wl,-z,defs
        -Wl,-z,nocopyreloc
        -Wl,--build-id
        -Wl,--gc-sections
        -Wl,--as-needed
        -Wl,-O2
    )
    
    directoryOptions=(--sysroot=${ANDROID_NDK}/platforms/android-9/arch-${arch} -no-canonical-prefixes)
    
    machineOptions=(-march=$march)

    if [[ $arch == arm ]]
    then
        gnustlPath="${gnustlPath}/thumb"
        linkerOptions+=("-mthumb")
    fi 

    "${ANDROID_NDK}/toolchains/${toolChain}/prebuilt/linux-x86_64/bin/${linker}" \
        "${linkerOptions[@]}" "${directoryOptions[@]}" "${machineOptions[@]}" \
        -lgcc -landroid -llog -lc -lm "-L${ANDROID_NDK}/platforms/android-9/arch-${arch}/usr/lib" \
        -o "${outputPath}/libreactnativejni.so"        

    stripRemoveSections=(
        -R .comment
    )

    "${ANDROID_NDK}/toolchains/${toolChain}/prebuilt/linux-x86_64/bin/${stripFile}" \
        --strip-unneeded \
        "${stripRemoveSections[@]}" \
        "${outputPath}/libreactnativejni.so"

    echo "Linker output for ${arch}: ${outputPath}/libreactnativejni.so"
}

cat <<EOF |
arm armeabi-v7a arm-linux-androideabi-4.8 arm-linux-androideabi armv7-a
x86 x86 x86-4.8 i686-linux-android x86
EOF

while read arch archSpec toolChain program march
do
    link $arch $archSpec $toolChain $program $march
done

echo "Done linking!"
